@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 1999-2011 Licq developers
+ * Copyright (C) 1999-2012 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -45,6 +45,7 @@
 #include <licq/pluginsignal.h>
 #include <licq/protocolmanager.h>
 #include <licq/protocolsignal.h>
+#include <licq/translator.h>
 #include <licq/userevents.h>
 
 #include "event_data.h"
@@ -641,6 +642,7 @@ void CLicqConsole::ProcessSignal(Licq::PluginSignal* s)
       gProtocolManager.updateUserAlias(s->userId());
       break;
     case Licq::PluginSignal::SignalNewProtocol:
+    case Licq::PluginSignal::SignalRemoveProtocol:
     //ignore for now
     break;
     default:
@@ -785,6 +787,7 @@ void CLicqConsole::ProcessDoneEvent(Licq::Event* e)
       win->wprintf("%A%Cfailed\n", m_cColorError->nAttr, m_cColorError->nColor);
         break;
       case Licq::Event::ResultError:
+      case Licq::Event::ResultUnsupported:
       win->wprintf("%A%Cerror\n", m_cColorError->nAttr, m_cColorError->nColor);
         break;
       case Licq::Event::ResultCancelled:
@@ -820,7 +823,8 @@ void CLicqConsole::ProcessDoneEvent(Licq::Event* e)
         {
           Licq::UserReadGuard u(e->userId());
           win->wprintf("%s is in %s mode:\n%s\n[Send \"urgent\" ('.u') to ignore]\n",
-              u->getAlias().c_str(), u->statusString().c_str(), u->autoResponse().c_str());
+              u->getAlias().c_str(), u->statusString().c_str(),
+              Licq::gTranslator.fromUtf8(u->autoResponse()).c_str());
         }
         else if (e->subResult() == Licq::Event::SubResultRefuse)
         {
@@ -843,7 +847,7 @@ void CLicqConsole::ProcessDoneEvent(Licq::Event* e)
           {
             Licq::UserReadGuard u(e->userId());
             win->wprintf("%s refused file: %s\n", u->getAlias().c_str(),
-                ea->response().c_str());
+                Licq::gTranslator.fromUtf8(ea->response()).c_str());
           }
 
           else
@@ -867,7 +871,7 @@ void CLicqConsole::ProcessDoneEvent(Licq::Event* e)
         {
           Licq::UserReadGuard u(e->userId());
           if (u.isLocked() && u->isAway() && u->ShowAwayMsg())
-            win->wprintf("%s\n", u->autoResponse().c_str());
+            win->wprintf("%s\n", Licq::gTranslator.fromUtf8(u->autoResponse()).c_str());
         }
     }
   }
@@ -1523,6 +1527,7 @@ void CLicqConsole::InputInfo(int cIn)
       winMain->wprintf("%C%AUpdate info...", m_cColorInfo->nColor,
                        m_cColorInfo->nAttr);
           winMain->event = gProtocolManager.requestUserInfo(data->userId);
+          winMain->eventUserId = data->userId;
       winMain->state = STATE_PENDING;
       return;
         }
@@ -1577,7 +1582,7 @@ void CLicqConsole::UserCommand_View(const Licq::UserId& userId, char *)
         u->isUser() ? u->getAlias().c_str() : "Server",
                      szTime, e->IsDirect() ? 'D' : '-',
                      e->IsMultiRec() ? 'M' : '-', e->IsUrgent() ? 'U' : '-',
-        e->text().c_str());
+        e->textLoc().c_str());
     wattron(winMain->Win(), A_BOLD);
     for (unsigned short i = 0; i < winMain->Cols() - 10; i++)
       waddch(winMain->Win(), ACS_HLINE);
@@ -1681,6 +1686,7 @@ void CLicqConsole::UserCommand_FetchAutoResponse(const Licq::UserId& userId, cha
   }
 
   winMain->event = gLicqDaemon->icqFetchAutoResponse(userId);
+  winMain->eventUserId = userId;
   // InputMessage just to catch the cancel key
   winMain->fProcessInput = &CLicqConsole::InputMessage;
   winMain->data = NULL;
@@ -1853,8 +1859,7 @@ static bool SendDirect(const Licq::UserId& userId, char c)
   Licq::UserReadGuard u(userId);
   if (u.isLocked())
   {
-    if (u->normalSocketDesc() == -1 &&
-        (u->Ip() == 0 || u->Port() == 0 || !u->isOnline()))
+    if (!u->canSendDirect())
       bDirect = false;
     else if (u->SendServer() && c != 'd' && c != 'u')
       bDirect = false;
@@ -1879,7 +1884,7 @@ void CLicqConsole::InputMessage(int cIn)
   {
   case STATE_PENDING:
     if (cIn == CANCEL_KEY)
-        Licq::gDaemon.cancelEvent(winMain->event);
+        gProtocolManager.cancelEvent(winMain->eventUserId, winMain->event);
     return;
 
   case STATE_MLE:
@@ -1917,7 +1922,9 @@ void CLicqConsole::InputMessage(int cIn)
       winMain->wprintf("%C%ASending message %s...", m_cColorInfo->nColor,
                        m_cColorInfo->nAttr,
                        !bDirect ? "through the server" : "direct");
-        winMain->event = gProtocolManager.sendMessage(data->userId, data->szMsg, flags);
+        winMain->event = gProtocolManager.sendMessage(data->userId,
+            Licq::gTranslator.toUtf8(data->szMsg), flags);
+        winMain->eventUserId = data->userId;
       winMain->state = STATE_PENDING;
       break;
     }
@@ -1931,7 +1938,9 @@ void CLicqConsole::InputMessage(int cIn)
     {
       winMain->wprintf("%C%ASending message through the server...",
                        m_cColorInfo->nColor, m_cColorInfo->nAttr);
-        winMain->event = gProtocolManager.sendMessage(data->userId, data->szMsg);
+        winMain->event = gProtocolManager.sendMessage(data->userId,
+            Licq::gTranslator.toUtf8(data->szMsg));
+        winMain->eventUserId = data->userId;
       winMain->state = STATE_PENDING;
     }
     else
@@ -1977,7 +1986,7 @@ void CLicqConsole::InputSendFile(int cIn)
   {
   case STATE_PENDING:
     if(cIn == CANCEL_KEY)
-        Licq::gDaemon.cancelEvent(winMain->event);
+        gProtocolManager.cancelEvent(winMain->eventUserId, winMain->event);
     return;
 
   case STATE_LE:
@@ -2052,7 +2061,9 @@ void CLicqConsole::InputSendFile(int cIn)
         flags |= Licq::ProtocolSignal::SendDirect;
 
       winMain->event = gProtocolManager.fileTransferPropose(data->userId,
-          data->szFileName, data->szDescription, lFileList, flags);
+          data->szFileName, Licq::gTranslator.toUtf8(data->szDescription),
+          lFileList, flags);
+      winMain->eventUserId = data->userId;
       break;
     }
   case STATE_QUERY:
@@ -2103,7 +2114,7 @@ void CLicqConsole::InputAutoResponse(int cIn)
       *sz = '\0';
       {
         Licq::OwnerWriteGuard o(LICQ_PPID);
-        o->setAutoResponse(data->szRsp);
+        o->setAutoResponse(Licq::gTranslator.toUtf8(data->szRsp));
         o->save(Licq::Owner::SaveOwnerInfo);
       }
       winMain->wprintf("%C%AAuto-response set.\n",
@@ -2151,7 +2162,7 @@ void CLicqConsole::InputUrl(int cIn)
   {
   case STATE_PENDING:
     if (cIn == CANCEL_KEY)
-        Licq::gDaemon.cancelEvent(winMain->event);
+        gProtocolManager.cancelEvent(winMain->eventUserId, winMain->event);
     return;
 
   case STATE_LE:
@@ -2199,8 +2210,10 @@ void CLicqConsole::InputUrl(int cIn)
       winMain->wprintf("%C%ASending URL %s...",
                        m_cColorInfo->nColor, m_cColorInfo->nAttr,
                        !bDirect ? "through the server" : "direct");
-      winMain->event = gProtocolManager.sendUrl(data->userId, data->szUrl,
-          data->szDesc, flags);
+      winMain->event = gProtocolManager.sendUrl(data->userId,
+          Licq::gTranslator.toUtf8(data->szUrl),
+          Licq::gTranslator.toUtf8(data->szDesc), flags);
+      winMain->eventUserId = data->userId;
       winMain->state = STATE_PENDING;
       break;
     }
@@ -2214,8 +2227,10 @@ void CLicqConsole::InputUrl(int cIn)
     {
       winMain->wprintf("%C%ASending URL through the server...",
                        m_cColorInfo->nColor, m_cColorInfo->nAttr);
-        winMain->event = gProtocolManager.sendUrl(data->userId, data->szUrl,
-            data->szDesc);
+        winMain->event = gProtocolManager.sendUrl(data->userId,
+            Licq::gTranslator.toUtf8(data->szUrl),
+            Licq::gTranslator.toUtf8(data->szDesc));
+        winMain->eventUserId = data->userId;
       winMain->state = STATE_PENDING;
     }
     else
@@ -2263,7 +2278,7 @@ void CLicqConsole::InputSms(int cIn)
   {
   case STATE_PENDING:
     if (cIn == CANCEL_KEY)
-        Licq::gDaemon.cancelEvent(winMain->event);
+        gProtocolManager.cancelEvent(winMain->eventUserId, winMain->event);
     return;
 
   case STATE_MLE:
@@ -2293,7 +2308,8 @@ void CLicqConsole::InputSms(int cIn)
       winMain->wprintf("%C%ASending SMS to %s ...", m_cColorInfo->nColor,
           m_cColorInfo->nAttr, u->getCellularNumber().c_str());
       winMain->event = gLicqDaemon->icqSendSms(data->userId,
-          u->getCellularNumber().c_str(), data->szMsg);
+          u->getCellularNumber(), data->szMsg);
+      winMain->eventUserId = data->userId;
       winMain->state = STATE_PENDING;
       break;
     }
@@ -2347,7 +2363,9 @@ void CLicqConsole::InputAuthorize(int cIn)
         winMain->wprintf("%C%ARefusing authorizing to %s...", m_cColorInfo->nColor,
             m_cColorInfo->nAttr, data->userId.toString().c_str());
       }
-      winMain->event = gProtocolManager.authorizeReply(data->userId, data->bUrgent, data->szMsg);
+      winMain->event = gProtocolManager.authorizeReply(data->userId, data->bUrgent,
+          Licq::gTranslator.toUtf8(data->szMsg));
+      winMain->eventUserId = data->userId;
 
       winMain->fProcessInput = &CLicqConsole::InputCommand;
       if (winMain->data != NULL)                           
@@ -2554,7 +2572,7 @@ void CLicqConsole::InputSearch(int cIn)
       if (cIn == CANCEL_KEY)
       {
         if (winMain->event != 0)
-          Licq::gDaemon.cancelEvent(winMain->event);
+          gProtocolManager.cancelEvent(winMain->eventUserId, winMain->event);
       }
       return;
     }
@@ -2581,6 +2599,7 @@ void CLicqConsole::InputSearch(int cIn)
                              m_cColorInfo->nColor, m_cColorInfo->nAttr);
 
             winMain->event = gLicqDaemon->icqSearchByUin(strtoul(data->szId, (char **)NULL, 10));
+            winMain->eventUserId = Licq::UserId(data->szId, LICQ_PPID);
             winMain->state = STATE_PENDING;
 
             return;
@@ -2859,6 +2878,7 @@ void CLicqConsole::InputSearch(int cIn)
                            data->nMinAge, data->nMaxAge, data->nGender, data->nLanguage,
                            data->szCity, data->szState, data->nCountryCode,
                            data->szCoName, data->szCoDept, data->szCoPos, "", data->bOnlineOnly);
+          winMain->eventUserId = Licq::UserId("0000", LICQ_PPID);
           winMain->state = STATE_PENDING;
 
           return;
@@ -2906,7 +2926,7 @@ void CLicqConsole::InputRegistrationWizard(int cIn)
       if(cIn == CANCEL_KEY)
       {
         if(winMain->event != 0)
-          Licq::gDaemon.cancelEvent(winMain->event);
+          gProtocolManager.cancelEvent(winMain->eventUserId, winMain->event);
       }
       return;
     }
@@ -3023,8 +3043,8 @@ void CLicqConsole::InputRegistrationWizard(int cIn)
             {
               Licq::OwnerWriteGuard o(LICQ_PPID);
               o->setPassword(data->szPassword1);
+              o->save(Licq::Owner::SaveOwnerInfo);
             }
-            Licq::gDaemon.SaveConf();
 
             winMain->wprintf("Save password? (y/N) ");
             winMain->state = STATE_QUERY;
@@ -3149,7 +3169,7 @@ void CLicqConsole::InputFileChatOffer(int cIn)
 
       // XXX hack
       gProtocolManager.fileTransferRefuse(data->userId,
-          data->szReason, f->Sequence(), 0, 0, false);
+          Licq::gTranslator.toUtf8(data->szReason), f->Sequence(), 0, 0, false);
 
       // We are done now
       winMain->wprintf("%ARefusing file from %s with reason: %Z%s\n",
@@ -3210,6 +3230,7 @@ void CLicqConsole::UserCommand_Secure(const Licq::UserId& userId, char *szStatus
         u->getAlias().c_str());
     u.unlock();
     winMain->event = gProtocolManager.secureChannelOpen(userId);
+    winMain->eventUserId = userId;
   }
   else if(strcasecmp(szStatus, "close") == 0)
   {
@@ -3217,6 +3238,7 @@ void CLicqConsole::UserCommand_Secure(const Licq::UserId& userId, char *szStatus
         u->getAlias().c_str());
     u.unlock();
     winMain->event = gProtocolManager.secureChannelClose(userId);
+    winMain->eventUserId = userId;
   }
   else
   {
