@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2010-2011 Licq Developers <licq-dev@googlegroups.com>
+ * Copyright (C) 2010-2012 Licq developers <licq-dev@googlegroups.com>
  *
  * Please refer to the COPYRIGHT file distributed with this source
  * distribution for the names of the individual contributors.
@@ -20,8 +20,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef JABBER_CLIENT_H
-#define JABBER_CLIENT_H
+#ifndef LICQJABBER_CLIENT_H
+#define LICQJABBER_CLIENT_H
 
 #include <boost/noncopyable.hpp>
 #include <gloox/client.h>
@@ -39,7 +39,7 @@ class ConnectionTCPClient;
 class RosterManager;
 }
 
-namespace Jabber
+namespace LicqJabber
 {
 
 class Config;
@@ -142,6 +142,6 @@ private:
   gloox::Presence::PresenceType statusToPresence(unsigned status);
 };
 
-} // namespace Jabber
+} // namespace LicqJabber
 
 #endif
