@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 1999-2010 Licq developers
+ * Copyright (C) 1999-2012 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,8 +44,10 @@ private:
    QLineEdit* myId;
    GroupComboBox* myGroup;
    ProtoComboBox* myProtocol;
+  QCheckBox* myReqAuthCheck;
 
 private slots:
+  void protocolChanged();
    void ok();
 };
 
