@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2004-2009,2011 Licq developers
+ * Copyright (C) 2004-2012 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,10 +24,10 @@
 
 class QCheckBox;
 class QLineEdit;
-class QSpinBox;
 
 namespace LicqQtGui
 {
+class SpecialSpinBox;
 
 class OwnerEditDlg : public QDialog
 {
@@ -44,7 +44,7 @@ private:
   QLineEdit* edtPassword;
   QCheckBox* chkSave;
   QLineEdit* myHostEdit;
-  QSpinBox* myPortSpin;
+  SpecialSpinBox* myPortSpin;
   unsigned long myPpid;
   bool myNewOwner;
 };
