@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 1999-2011 Licq developers
+ * Copyright (C) 1999-2012 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -232,9 +232,11 @@ void RegisterUserDlg::gotNewOwner(const Licq::UserId& userId)
   {
     Licq::OwnerWriteGuard o(LICQ_PPID);
     if (o.isLocked())
+    {
       o->SetSavePassword(mySavePassword->isChecked());
+      o->save(Licq::Owner::SaveOwnerInfo);
+    }
   }
-  Licq::gDaemon.SaveConf();
 
   // Mark that we have finished
   mySuccess = true;
