@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 1999-2011 Licq developers
+ * Copyright (C) 1999-2012 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,18 +30,16 @@
 #include <QHBoxLayout>
 #include <QPushButton>
 #include <QRegExp>
-#include <QTextCodec>
 #include <QVBoxLayout>
 
 #include <licq/contactlist/user.h>
-#include <licq/daemon.h>
 #include <licq/event.h>
 #include <licq/icq/icq.h>
+#include <licq/protocolmanager.h>
 
 #include "core/signalmanager.h"
 
 #include "helpers/support.h"
-#include "helpers/usercodec.h"
 
 #include "widgets/mledit.h"
 
@@ -77,20 +75,16 @@ ShowAwayMsgDlg::ShowAwayMsgDlg(const Licq::UserId& userId, bool fetch, QWidget*
   connect(buttons, SIGNAL(rejected()), SLOT(close()));
   lay->addWidget(buttons);
 
-  bool bSendServer = true;
   {
     Licq::UserReadGuard u(myUserId);
-    const QTextCodec* codec = UserCodec::codecForUser(*u);
     chkShowAgain->setChecked(u->ShowAwayMsg());
 
     setWindowTitle(QString(tr("%1 Response for %2"))
         .arg(u->statusString(true, false).c_str())
         .arg(QString::fromUtf8(u->getAlias().c_str())));
 
-    if (fetch)
-      bSendServer = (u->normalSocketDesc() <= 0 && u->Version() > 6);
-    else
-      mleAwayMsg->setText(codec->toUnicode(u->autoResponse().c_str()));
+    if (!fetch)
+      mleAwayMsg->setText(QString::fromUtf8(u->autoResponse().c_str()));
   }
 
   if (fetch)
@@ -98,7 +92,7 @@ ShowAwayMsgDlg::ShowAwayMsgDlg(const Licq::UserId& userId, bool fetch, QWidget*
     mleAwayMsg->setEnabled(false);
     connect(gGuiSignalManager, SIGNAL(doneUserFcn(const Licq::Event*)),
         SLOT(doneEvent(const Licq::Event*)));
-    icqEventTag = gLicqDaemon->icqFetchAutoResponse(myUserId, bSendServer);
+    icqEventTag = gLicqDaemon->icqFetchAutoResponse(myUserId);
   }
 
   show();
@@ -112,7 +106,7 @@ ShowAwayMsgDlg::~ShowAwayMsgDlg()
   }
 
   if (icqEventTag != 0)
-    Licq::gDaemon.cancelEvent(icqEventTag);
+    Licq::gProtocolManager.cancelEvent(myUserId, icqEventTag);
 }
 
 void ShowAwayMsgDlg::doneEvent(const Licq::Event* e)
@@ -132,6 +126,7 @@ void ShowAwayMsgDlg::doneEvent(const Licq::Event* e)
     switch (e->Result())
     {
       case Licq::Event::ResultFailed:
+      case Licq::Event::ResultUnsupported:
       result = tr("failed");
         break;
       case Licq::Event::ResultTimedout:
@@ -156,23 +151,19 @@ void ShowAwayMsgDlg::doneEvent(const Licq::Event* e)
   if (isOk)
   {
     Licq::UserReadGuard u(myUserId);
-    const QTextCodec* codec = UserCodec::codecForUser(*u);
-    const char* szAutoResp =
+    QString strResponse = QString::fromUtf8(
       (e->ExtendedAck() && !e->ExtendedAck()->accepted()) ?
        e->ExtendedAck()->response().c_str() :
-       u->autoResponse().c_str();
+       u->autoResponse().c_str());
 
     if (u->protocolId() == LICQ_PPID && QString(u->accountId().c_str())[0].isLetter())
     {
       // Strip HTML
-      QString strResponse(codec->toUnicode(szAutoResp));
       QRegExp regExp("<.*>");
       regExp.setMinimal(true);
       strResponse.replace(regExp, "");
-      mleAwayMsg->setText(strResponse);
     }
-    else
-      mleAwayMsg->setText(codec->toUnicode(szAutoResp));
+    mleAwayMsg->setText(strResponse);
 
     mleAwayMsg->setEnabled(true);
   }
