@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2001-2010 Licq developers
+ * Copyright (C) 2001-2010,2012 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,17 +20,7 @@
 #ifndef USERCODEC_H
 #define USERCODEC_H
 
-#include <QObject>
-
-class QTextCodec;
-
-class CChatUser;
-
-namespace Licq
-{
-class User;
-class UserId;
-}
+#include <QString>
 
 namespace LicqQtGui
 {
@@ -41,26 +31,12 @@ public:
   {
     const char* script;
     const char* encoding;
-    int mib;
-    unsigned char charset;
     bool isMinimal;
   };
   static encoding_t m_encodings[];
 
-  // Retrieves the default codec
-  static const QTextCodec* defaultEncoding();
-  // Retrieves the codec for an LicqUser object
-  static const QTextCodec* codecForUser(const Licq::User* u);
-  // Retrieves the codec for an CChatUser object
-  static const QTextCodec* codecForCChatUser(CChatUser* u);
-  // Retrieves the codec for a proto user
-  static const QTextCodec* codecForUserId(const Licq::UserId& userId);
-
-  static QByteArray encodingForMib(int mib);
-  static QString nameForEncoding(const QByteArray& encoding);
-  static QByteArray encodingForName(const QString& descriptiveName);
-  static unsigned char charsetForName(QByteArray name);
-  static QByteArray nameForCharset(unsigned char charset);
+  static QString nameForEncoding(int index);
+  static int encodingForName(const QString& descriptiveName);
 };
 
 } // namespace LicqQtGui
