@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2000-2011 Licq developers
+ * Copyright (C) 2000-2012 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,7 +43,6 @@
 #include <QPushButton>
 #include <QShortcut>
 #include <QSplitter>
-#include <QTextCodec>
 #include <QToolBar>
 #include <QToolButton>
 #include <QVBoxLayout>
@@ -86,8 +85,6 @@
 #include "dialogs/mmsenddlg.h"
 #include "dialogs/showawaymsgdlg.h"
 
-#include "helpers/usercodec.h"
-
 #include "views/mmuserview.h"
 #include "views/userview.h"
 
@@ -166,25 +163,22 @@ UserSendEvent::UserSendEvent(int type, const Licq::UserId& userId, QWidget* pare
   QMenu* mnuSendType = new QMenu(this);
   mnuSendType->addActions(myEventTypeGroup->actions());
 
-  myEventTypeMenu = myToolBar->addAction(tr("Message type"), this, SLOT(showSendTypeMenu()));
+  myEventTypeMenu = myToolBar->addAction(tr("Message Type"), this, SLOT(showSendTypeMenu()));
   myEventTypeMenu->setMenu(mnuSendType);
   if (eventTypesCount <= 1)
     myEventTypeMenu->setEnabled(false);
 
-  mySendServerCheck = myToolBar->addAction(tr("Send through server"));
+  mySendServerCheck = myToolBar->addAction(tr("Send Through Server"));
   mySendServerCheck->setCheckable(true);
 
-  bool canSendDirect = (mySendFuncs & Licq::ProtocolPlugin::CanSendDirect);
+  bool canSendDirect = false;
 
   {
     Licq::UserReadGuard u(myUsers.front());
     if (u.isLocked())
     {
-      mySendServerCheck->setChecked(u->SendServer() ||
-          (!u->isOnline() && u->normalSocketDesc() == -1));
-
-      if (u->InvisibleList() || (u->Port() == 0 && u->normalSocketDesc() == -1))
-        canSendDirect = false;
+      mySendServerCheck->setChecked(u->SendServer());
+      canSendDirect = u->canSendDirect();
     }
   }
   if (!canSendDirect)
@@ -231,7 +225,6 @@ UserSendEvent::UserSendEvent(int type, const Licq::UserId& userId, QWidget* pare
     connect(myHistoryView, SIGNAL(messageAdded()), SLOT(messageAdded()));
 
     Licq::UserReadGuard u(myUsers.front());
-    int userSocketDesc = (u.isLocked() ? u->normalSocketDesc() : -1);
     int historyCount = Config::Chat::instance()->showHistoryCount();
     int historyTime = Config::Chat::instance()->showHistoryTime();
     if (u.isLocked() && (historyCount > 0 || historyTime > 0))
@@ -264,7 +257,6 @@ UserSendEvent::UserSendEvent(int type, const Licq::UserId& userId, QWidget* pare
         }
 
         bool bUseHTML = !isdigit(u->accountId()[1]);
-        const QTextCodec* myCodec = UserCodec::codecForUser(*u);
         QString contactName = QString::fromUtf8(u->getAlias().c_str());
         QString ownerName;
         {
@@ -293,11 +285,7 @@ UserSendEvent::UserSendEvent(int type, const Licq::UserId& userId, QWidget* pare
         {
           QString str;
           date.setTime_t((*lHistoryIter)->Time());
-          QString messageText;
-          if ((*lHistoryIter)->eventType() == Licq::UserEvent::TypeSms) // SMSs are always in UTF-8
-            messageText = QString::fromUtf8((*lHistoryIter)->text().c_str());
-          else
-            messageText = myCodec->toUnicode((*lHistoryIter)->text().c_str());
+          QString messageText = QString::fromUtf8((*lHistoryIter)->text().c_str());
 
           myHistoryView->addMsg(
               (*lHistoryIter)->isReceiver(),
@@ -386,9 +374,9 @@ UserSendEvent::UserSendEvent(int type, const Licq::UserId& userId, QWidget* pare
     }
 
     // Do we already have an open socket?
-    if (myConvoId == 0 && userSocketDesc != 1)
+    if (myConvoId == 0)
     {
-      Licq::Conversation* convo = gConvoManager.getFromSocket(userSocketDesc);
+      Licq::Conversation* convo = gConvoManager.getFromUser(myUsers.front());
       if (convo != NULL)
         myConvoId = convo->id();
     }
@@ -523,7 +511,7 @@ UserSendEvent::UserSendEvent(int type, const Licq::UserId& userId, QWidget* pare
   {
     Licq::UserReadGuard u(myUsers.front());
     updatePicture(*u);
-    mySmsPhoneEdit->setText(myCodec->toUnicode(u->getCellularNumber().c_str()));
+    mySmsPhoneEdit->setText(QString::fromUtf8(u->getCellularNumber().c_str()));
   }
   updateShortcuts();
 
@@ -986,7 +974,7 @@ void UserSendEvent::retrySend(const Licq::Event* e, unsigned flags)
           // we take the maximum length, then convert back to a Unicode string
           // and then search for Unicode whitespaces.
           messageRaw = Licq::gTranslator.returnToUnix(wholeMessageRaw.mid(wholeMessagePos, maxSize).data()).c_str();
-          message = myCodec->toUnicode(messageRaw);
+          message = QString::fromUtf8(messageRaw);
 
           if ((wholeMessageRaw.length() - wholeMessagePos) > maxSize)
           {
@@ -1001,7 +989,7 @@ void UserSendEvent::retrySend(const Licq::Event* e, unsigned flags)
             if (foundIndex > 0)
             {
               message.truncate(foundIndex + 1);
-              messageRaw = myCodec->fromUnicode(message);
+              messageRaw = message.toUtf8();
             }
           }
         }
@@ -1086,7 +1074,7 @@ void UserSendEvent::retrySend(const Licq::Event* e, unsigned flags)
 
       //TODO in the daemon
       icqEventTag = gLicqDaemon->icqSendSms(myUsers.front(),
-          ue->number().c_str(), ue->message().c_str());
+          ue->number(), ue->message());
       break;
     }
 
@@ -1257,7 +1245,7 @@ void UserSendEvent::send()
 
   if (myType == MessageEvent)
   {
-    QByteArray wholeMessageRaw(Licq::gTranslator.returnToDos(myCodec->fromUnicode(myMessageEdit->toPlainText()).data()).c_str());
+    QByteArray wholeMessageRaw(Licq::gTranslator.returnToDos(myMessageEdit->toPlainText().toUtf8().data()).c_str());
     int wholeMessagePos = 0;
 
     bool needsSplitting = false;
@@ -1278,7 +1266,7 @@ void UserSendEvent::send()
         // we take the maximum length, then convert back to a Unicode string
         // and then search for Unicode whitespaces.
         messageRaw = Licq::gTranslator.returnToUnix(wholeMessageRaw.mid(wholeMessagePos, maxSize).data()).c_str();
-        QString message = myCodec->toUnicode(messageRaw);
+        QString message = QString::fromUtf8(messageRaw);
 
         if (wholeMessageRaw.length() - wholeMessagePos > maxSize)
         {
@@ -1293,13 +1281,13 @@ void UserSendEvent::send()
           if (foundIndex > 0)
           {
             message.truncate(foundIndex + 1);
-            messageRaw = myCodec->fromUnicode(message);
+            messageRaw = message.toUtf8();
           }
         }
       }
       else
       {
-        messageRaw = myCodec->fromUnicode(myMessageEdit->toPlainText());
+        messageRaw = myMessageEdit->toPlainText().toUtf8();
       }
 
       unsigned long icqEventTag = gProtocolManager.sendMessage(
@@ -1323,8 +1311,8 @@ void UserSendEvent::send()
       case UrlEvent:
         icqEventTag = gProtocolManager.sendUrl(
             myUsers.front(),
-            myUrlEdit->text().toLatin1().constData(),
-            myCodec->fromUnicode(myMessageEdit->toPlainText()).data(),
+            myUrlEdit->text().toUtf8().constData(),
+            myMessageEdit->toPlainText().toUtf8().data(),
             flags,
             &myIcqColor);
         break;
@@ -1343,13 +1331,13 @@ void UserSendEvent::send()
           //TODO in daemon
           icqEventTag = gLicqDaemon->icqChatRequest(
               myUsers.front(),
-              myCodec->fromUnicode(myMessageEdit->toPlainText()).data(),
+              myMessageEdit->toPlainText().toUtf8().data(),
               flags);
         else
           icqEventTag = gLicqDaemon->icqMultiPartyChatRequest(
               myUsers.front(),
-              myCodec->fromUnicode(myMessageEdit->toPlainText()).data(),
-              myCodec->fromUnicode(myChatClients).data(),
+              myMessageEdit->toPlainText().toUtf8().data(),
+              myChatClients.toUtf8().data(),
               myChatPort,
               flags);
         break;
@@ -1358,15 +1346,15 @@ void UserSendEvent::send()
         //TODO in daemon
         icqEventTag = gProtocolManager.fileTransferPropose(
             myUsers.front(),
-            myCodec->fromUnicode(myFileEdit->text()).data(),
-            myCodec->fromUnicode(myMessageEdit->toPlainText()).data(),
+            QFile::encodeName(myFileEdit->text()).data(),
+            myMessageEdit->toPlainText().toUtf8().data(),
             myFileList,
             flags);
         break;
 
       case SmsEvent:
         icqEventTag = gLicqDaemon->icqSendSms(myUsers.front(),
-            mySmsPhoneEdit->text().toLatin1().constData(),
+            mySmsPhoneEdit->text().toUtf8().constData(),
             myMessageEdit->toPlainText().toUtf8().data());
         break;
     }
@@ -1470,6 +1458,7 @@ void UserSendEvent::eventDoneReceived(const Licq::Event* e)
       result = tr("cancelled");
       break;
     case Licq::Event::ResultFailed:
+    case Licq::Event::ResultUnsupported:
       result = tr("failed");
       break;
     case Licq::Event::ResultTimedout:
@@ -1536,7 +1525,7 @@ void UserSendEvent::eventDoneReceived(const Licq::Event* e)
       msg = tr("%1 is in %2 mode:\n%3\nSend...")
           .arg(QString::fromUtf8(u->getAlias().c_str()))
           .arg(u->statusString().c_str())
-          .arg(myCodec->toUnicode(u->autoResponse().c_str()));
+          .arg(QString::fromUtf8(u->autoResponse().c_str()));
 
       u->SetShowAwayMsg(false);
     }
@@ -1595,7 +1584,7 @@ void UserSendEvent::eventDoneReceived(const Licq::Event* e)
           break;
         QString s = !e->ExtendedAck() ?
           tr("No reason provided") :
-          myCodec->toUnicode(e->ExtendedAck()->response().c_str());
+            QString::fromUtf8(e->ExtendedAck()->response().c_str());
         QString result = tr("File transfer with %1 refused:\n%2")
           .arg(QString::fromUtf8(u->getAlias().c_str()))
           .arg(s);
@@ -1616,7 +1605,7 @@ void UserSendEvent::eventDoneReceived(const Licq::Event* e)
         Licq::UserReadGuard u(myUsers.front());
         QString s = !e->ExtendedAck() ?
           tr("No reason provided") :
-          myCodec->toUnicode(e->ExtendedAck()->response().c_str());
+            QString::fromUtf8(e->ExtendedAck()->response().c_str());
         QString result = tr("Chat with %1 refused:\n%2")
           .arg(!u.isLocked() ? u->accountId().c_str() : QString::fromUtf8(u->getAlias().c_str()))
           .arg(s);
@@ -1638,8 +1627,6 @@ void UserSendEvent::eventDoneReceived(const Licq::Event* e)
   emit eventSent(e);
   if (Config::Chat::instance()->msgChatView() && myHistoryView != NULL)
   {
-    myHistoryView->GotoEnd();
-
     myMessageEdit->clear();
     myMessageEdit->setFocus();
 
@@ -1677,7 +1664,7 @@ void UserSendEvent::cancelSend()
   if (tabDlg != NULL && tabDlg->tabIsSelected(this))
     tabDlg->setWindowTitle(myTitle);
 
-  Licq::gDaemon.cancelEvent(icqEventTag);
+  gProtocolManager.cancelEvent(myUsers.front(), icqEventTag);
 }
 
 void UserSendEvent::changeEventType(QAction* action)
@@ -1720,7 +1707,8 @@ void UserSendEvent::clearNewEvents()
 
 void UserSendEvent::closeDialog()
 {
-  gProtocolManager.sendTypingNotification(myUsers.front(), false, myConvoId);
+  if (mySendTypingTimer->isActive())
+    gProtocolManager.sendTypingNotification(myUsers.front(), false, myConvoId);
 
   if (Config::Chat::instance()->msgChatView())
   {
