@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2010-2011 Licq developers
+ * Copyright (C) 2010-2012 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include <licq/contactlist/usermanager.h>
 
 #include <map>
+#include <set>
 
 #include <licq/thread/readwritemutex.h>
 #include <licq/userid.h>
@@ -31,12 +32,10 @@
 namespace LicqDaemon
 {
 class Group;
-class Owner;
-class User;
 
-typedef std::map<Licq::UserId, User*> UserMap;
+typedef std::map<Licq::UserId, Licq::User*> UserMap;
 typedef std::map<int, Group*> GroupMap;
-typedef std::map<unsigned long, Owner*> OwnerMap;
+typedef std::map<unsigned long, Licq::Owner*> OwnerMap;
 
 class UserManager : public Licq::UserManager
 {
@@ -50,14 +49,32 @@ public:
   void shutdown();
 
   bool Load();
-  unsigned short GenerateSID();
-  bool UpdateUsersInGroups();
+  void writeToUserHistory(Licq::User* user, const std::string& text);
 
   /**
-   * Save user list to configuration file
-   * Note: This function assumes that the user list is already locked.
+   * Load owners and users for a protocol
+   * Called by ProtocolManager when protocol is loaded
+   *
+   * @param protocolId Protocol to load contacts for
    */
-  void saveUserList() const;
+  void loadProtocol(unsigned long protocolId);
+
+  /**
+   * Check if protocol unloading should be allowed
+   * Called by ProtocolManager before protocol is unloaded
+   *
+   * @param protocolId Id of protocol to be unloaded
+   * @return False if unloading should be aborted
+   */
+  bool allowUnloadProtocol(unsigned long protocolId);
+
+  /**
+   * Prepare to unload a protocol
+   * Called by ProtocolManager when protocol is unloaded
+   *
+   * @param protocolId Protocol to be unloaded
+   */
+  void unloadProtocol(unsigned long protocolId);
 
   /**
    * Fetch and lock the user list map
@@ -145,19 +162,18 @@ public:
   bool userExists(const Licq::UserId& userId);
   Licq::UserId ownerUserId(unsigned long ppid);
   bool isOwner(const Licq::UserId& userId);
-  unsigned long icqOwnerUin();
   void notifyUserUpdated(const Licq::UserId& userId, unsigned long subSignal);
   bool addUser(const Licq::UserId& userId, bool permanent = true,
       bool addToServer = true, unsigned short groupId = 0);
-  bool makeUserPermanent(const Licq::UserId& userId, bool addToServer = true, int groupId = 0);
-  void removeUser(const Licq::UserId& userId, bool removeFromServer = true);
+  void removeUser(const Licq::UserId& userId);
+  void removeLocalUser(const Licq::UserId& userId);
   bool groupExists(int groupId);
-  int AddGroup(const std::string& name, unsigned short icqGroupId = 0);
+  int AddGroup(const std::string& name);
   void RemoveGroup(int groupId);
-  bool RenameGroup(int groupId, const std::string& name, bool sendUpdate = true);
+  bool RenameGroup(int groupId, const std::string& name, unsigned long skipProtocolId = 0);
   void ModifyGroupSorting(int groupId, int newIndex);
-  void ModifyGroupID(int groupId, unsigned short icqGroupId);
-  int GetGroupFromID(unsigned short icqGroupId);
+  void setGroupServerId(int groupId, unsigned long protocolId, unsigned long serverId);
+  int getGroupFromServerId(unsigned long protocolId, unsigned long serverId);
   int GetGroupFromName(const std::string& name);
   std::string GetGroupNameFromGroup(int groupId);
   void setUserInGroup(const Licq::UserId& userId, int groupId,
@@ -170,8 +186,42 @@ public:
   unsigned int NumGroups();
 
 private:
+  /**
+   * Load user list from configuration file
+   *
+   * @param ownerId Owner to load users for
+   */
+  void loadUserList(const Licq::UserId& ownerId);
+
+  void saveOwnerList();
+
+  /**
+   * Save user list to configuration file
+   * Note: This function assumes that the user list is already locked.
+   *
+   * @param ownerId Owner to save user list for
+   */
+  void saveUserList(const Licq::UserId& ownerId);
+
   void SaveGroups();
 
+  /**
+   * Create a user object, either Licq::User or protocol subclass
+   *
+   * @param id User id
+   * @param temporary True if user isn't premanently added to contact list
+   * @return A created Licq::User
+   */
+  Licq::User* createUser(const Licq::UserId& id, bool temporary = false);
+
+  /**
+   * Create an owner object, either Licq::Owner or protocol subclass
+   *
+   * @param id Owner user id
+   * @return a created Licq::Owner
+   */
+  Licq::Owner* createOwner(const Licq::UserId& id);
+
   Licq::ReadWriteMutex myGroupListMutex;
   Licq::ReadWriteMutex myUserListMutex;
   Licq::ReadWriteMutex myOwnerListMutex;
@@ -179,6 +229,7 @@ private:
   GroupMap myGroups;
   UserMap myUsers;
   OwnerMap myOwners;
+  std::set<Licq::UserId> myConfiguredOwners;
   bool m_bAllowSave;
   std::string myDefaultEncoding;
 };
