@@ -1,13 +1,25 @@
-/* ----------------------------------------------------------------------------
- * Licq - A ICQ Client for Unix
- * Copyright (C) 1998-2011 Licq developers
+/*
+ * This file is part of Licq, an instant messaging client for UNIX.
+ * Copyright (C) 1998-2012 Licq developers <licq-dev@googlegroups.com>
  *
- * This program is licensed under the terms found in the LICENSE file.
+ * Licq is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * Licq is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Licq; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
 
-#include <licq/icq//filetransfer.h>
+#include "filetransfer.h"
 
 #include <cstdio>
 #include <ctype.h>
@@ -22,11 +34,11 @@
 
 #include <licq/logging/log.h>
 #include <licq/contactlist/owner.h>
-#include <licq/contactlist/user.h>
 #include <licq/daemon.h>
 
 #include "icq.h"
-#include "packet.h"
+#include "packet-tcp.h"
+#include "user.h"
 #include "../gettext.h"
 
 #define DEBUG_THREADS(x)
@@ -42,6 +54,7 @@ const unsigned short FT_STATE_SENDINGxFILE = 7;
 const unsigned short FT_STATE_CONFIRMINGxFILE = 8;
 
 using namespace std;
+using namespace LicqIcq;
 using Licq::Log;
 using Licq::gDaemon;
 using Licq::gLog;
@@ -190,7 +203,8 @@ pthread_mutex_t CFileTransferManager::thread_cancel_mutex
                                                    = PTHREAD_MUTEX_INITIALIZER;
 
 CFileTransferManager::CFileTransferManager(const Licq::UserId& userId)
-  : m_bThreadRunning(false),
+  : myPrivate(new Private()),
+    m_bThreadRunning(false),
     myUserId(userId)
 {
   m_nSession = rand();
@@ -326,10 +340,12 @@ void CFileTransferManager::sendFiles(const list<string>& pathNames, unsigned sho
 //-----CFileTransferManager::ConnectToFileServer-----------------------------
 bool CFileTransferManager::ConnectToFileServer(unsigned short nPort)
 {
+  LICQ_D();
+
   bool bTryDirect;
   bool bSendIntIp;
   {
-    Licq::UserReadGuard u(myUserId);
+    UserReadGuard u(myUserId);
     if (!u.isLocked())
       return false;
 
@@ -341,7 +357,7 @@ bool CFileTransferManager::ConnectToFileServer(unsigned short nPort)
   if (bTryDirect)
   {
     gLog.info(tr("File Transfer: Connecting to server."));
-    bSuccess = gIcqProtocol.openConnectionToUser(myUserId, &ftSock, nPort);
+    bSuccess = gIcqProtocol.openConnectionToUser(myUserId, &d->mySock, nPort);
    }
 
   bool bResult = false;
@@ -377,15 +393,17 @@ bool CFileTransferManager::ConnectToFileServer(unsigned short nPort)
 
 bool CFileTransferManager::SendFileHandshake()
 {
+  LICQ_D();
+
   gLog.info(tr("File Transfer: Shaking hands."));
 
   // Send handshake packet:
   unsigned short nVersion;
   {
-    Licq::UserReadGuard u(myUserId);
+    UserReadGuard u(myUserId);
     nVersion = u->ConnectionVersion();
   }
-  if (!IcqProtocol::handshake_Send(&ftSock, myUserId, LocalPort(), nVersion, false))
+  if (!IcqProtocol::handshake_Send(&d->mySock, myUserId, LocalPort(), nVersion, false))
     return false;
 
   // Send init packet:
@@ -396,8 +414,8 @@ bool CFileTransferManager::SendFileHandshake()
 
   m_nState = FT_STATE_WAITxFORxSERVERxINIT;
 
-  sockman.AddSocket(&ftSock);
-  sockman.DropSocket(&ftSock);
+  sockman.AddSocket(&d->mySock);
+  sockman.DropSocket(&d->mySock);
 
   return true;
 }
@@ -406,15 +424,17 @@ bool CFileTransferManager::SendFileHandshake()
 //-----CFileTransferManager::AcceptReverseConnection-------------------------
 void CFileTransferManager::AcceptReverseConnection(Licq::TCPSocket* s)
 {
-  if (ftSock.Descriptor() != -1)
+  LICQ_D();
+
+  if (d->mySock.Descriptor() != -1)
   {
     gLog.warning(tr("File Transfer: Attempted reverse connection when already connected."));
     return;
   }
 
-  ftSock.TransferConnectionFrom(*s);
-  sockman.AddSocket(&ftSock);
-  sockman.DropSocket(&ftSock);
+  d->mySock.TransferConnectionFrom(*s);
+  sockman.AddSocket(&d->mySock);
+  sockman.DropSocket(&d->mySock);
 
   m_nState = FT_STATE_WAITxFORxCLIENTxINIT;
 
@@ -428,12 +448,14 @@ void CFileTransferManager::AcceptReverseConnection(Licq::TCPSocket* s)
 //-----CFileTransferManager::ProcessPacket-------------------------------------------
 bool CFileTransferManager::ProcessPacket()
 {
-  if (!ftSock.RecvPacket())
+  LICQ_D();
+
+  if (!d->mySock.RecvPacket())
   {
-    if (ftSock.Error() == 0)
+    if (d->mySock.Error() == 0)
       gLog.info(tr("File Transfer: Remote end disconnected."));
     else
-      gLog.warning(tr("File Transfer: Lost remote end: %s"), ftSock.errorStr().c_str());
+      gLog.warning(tr("File Transfer: Lost remote end: %s"), d->mySock.errorStr().c_str());
     if (m_nState == FT_STATE_WAITxFORxFILExINFO)
       m_nResult = FT_DONExBATCH;
     else
@@ -441,8 +463,9 @@ bool CFileTransferManager::ProcessPacket()
     return false;
   }
 
-  if (!ftSock.RecvBufferFull()) return true;
-  CBuffer &b = ftSock.RecvBuffer();
+  if (!d->mySock.RecvBufferFull())
+    return true;
+  CBuffer& b = d->mySock.RecvBuffer();
 
   switch(m_nState)
   {
@@ -452,12 +475,12 @@ bool CFileTransferManager::ProcessPacket()
     {
       CBuffer tmp(b); // we need to save a copy for later
 
-      if (!IcqProtocol::Handshake_Recv(&ftSock, LocalPort(), false))
+      if (!IcqProtocol::Handshake_Recv(&d->mySock, LocalPort(), false))
         break;
       gLog.info(tr("File Transfer: Received handshake."));
 
       unsigned long nId = 0;
-      if (ftSock.Version() == 7 || ftSock.Version() == 8)
+      if (d->mySock.Version() == 7 || d->mySock.Version() == 8)
       {
         CPacketTcp_Handshake_v7 hand(&tmp);
         nId = hand.Id();
@@ -505,6 +528,7 @@ bool CFileTransferManager::ProcessPacket()
 
     case FT_STATE_WAITxFORxCLIENTxINIT:
     {
+      b.unpackUInt16LE(); // Packet length
       unsigned char nCmd = b.UnpackChar();
       if (nCmd == 0x05)
       {
@@ -522,7 +546,7 @@ bool CFileTransferManager::ProcessPacket()
       m_nBatchFiles = b.UnpackUnsignedLong();
       m_nBatchSize = b.UnpackUnsignedLong();
       m_nSpeed = b.UnpackUnsignedLong();
-      myRemoteName = b.unpackString();
+      myRemoteName = b.unpackShortStringLE();
 
       m_nBatchStartTime = time(NULL);
       m_nBatchBytesTransfered = m_nBatchPos = 0;
@@ -552,6 +576,7 @@ bool CFileTransferManager::ProcessPacket()
 
     case FT_STATE_WAITxFORxFILExINFO:
     {
+      b.unpackUInt16LE(); // Packet length
       unsigned char nCmd = b.UnpackChar();
       if (nCmd == 0x05)
       {
@@ -559,7 +584,7 @@ bool CFileTransferManager::ProcessPacket()
         gLog.info(tr("File Transfer: Speed set to %ld%%."), nSpeed);
         break;
       }
-      if (nCmd == 0x06 && b.getDataSize() == 1)
+      if (nCmd == 0x06 && b.getDataSize() == 3)
       {
         gLog.info(tr("File Transfer: Ignoring a possible erroneous packet."));
         break;
@@ -571,7 +596,7 @@ bool CFileTransferManager::ProcessPacket()
         return false;
       }
       b.UnpackChar();
-      myFileName = b.unpackString();
+      myFileName = b.unpackShortStringLE();
 
       // Remove any preceeding path info from the filename for security
       // reasons
@@ -616,7 +641,7 @@ bool CFileTransferManager::ProcessPacket()
       }
 
       // Write the new data to the file and empty the buffer
-      CBuffer &b = ftSock.RecvBuffer();
+      b.unpackUInt16LE(); // Packet length
       char nCmd = b.UnpackChar();
       if (nCmd == 0x05)
       {
@@ -633,8 +658,8 @@ bool CFileTransferManager::ProcessPacket()
       }
 
       errno = 0;
-      size_t nBytesWritten = write(m_nFileDesc, b.getDataPosRead(), b.getDataSize() - 1);
-      if (nBytesWritten != b.getDataSize() - 1)
+      size_t nBytesWritten = write(m_nFileDesc, b.getDataPosRead(), b.getDataSize() - 3);
+      if (nBytesWritten != b.getDataSize() - 3)
       {
         gLog.error(tr("File Transfer: Write error: %s."),
             errno == 0 ? "Disk full (?)" : strerror(errno));
@@ -688,6 +713,7 @@ bool CFileTransferManager::ProcessPacket()
 
     case FT_STATE_WAITxFORxSERVERxINIT:
     {
+      b.unpackUInt16LE(); // Packet length
       char nCmd = b.UnpackChar();
       if (nCmd == 0x05)
       {
@@ -702,7 +728,7 @@ bool CFileTransferManager::ProcessPacket()
         return false;
       }
       m_nSpeed = b.UnpackUnsignedLong();
-      myRemoteName = b.unpackString();
+      myRemoteName = b.unpackShortStringLE();
 
       // Send file info packet
       CPFile_Info p(*myPathNameIter);
@@ -734,6 +760,7 @@ bool CFileTransferManager::ProcessPacket()
     case FT_STATE_WAITxFORxSTART:
     {
       // contains the seek value
+      b.unpackUInt16LE(); // Packet length
       char nCmd = b.UnpackChar();
       if (nCmd == 0x05)
       {
@@ -776,6 +803,7 @@ bool CFileTransferManager::ProcessPacket()
 
     case FT_STATE_SENDINGxFILE:
     {
+      b.unpackUInt16LE(); // Packet length
       char nCmd = b.UnpackChar();
       if (nCmd == 0x05)
       {
@@ -797,7 +825,7 @@ bool CFileTransferManager::ProcessPacket()
 
   } // switch
 
-  ftSock.ClearRecvBuffer();
+  d->mySock.ClearRecvBuffer();
 
   return true;
 }
@@ -1006,9 +1034,11 @@ bool CFileTransferManager::SendPacket(CPacket *p)
 //-----CFileTransferManager::SendBuffer----------------------------------------------
 bool CFileTransferManager::SendBuffer(CBuffer *b)
 {
-  if (!ftSock.SendPacket(b))
+  LICQ_D();
+
+  if (!d->mySock.send(*b))
   {
-    gLog.warning(tr("File Transfer: Send error: %s"), ftSock.errorStr().c_str());
+    gLog.warning(tr("File Transfer: Send error: %s"), d->mySock.errorStr().c_str());
     return false;
   }
   return true;
@@ -1046,8 +1076,10 @@ void CFileTransferManager::CloseFileTransfer()
 //----CFileTransferManager::CloseConnection----------------------------------
 void CFileTransferManager::CloseConnection()
 {
+  LICQ_D();
+
   sockman.CloseSocket(ftServer.Descriptor(), false, false);
-  sockman.CloseSocket(ftSock.Descriptor(), false, false);
+  sockman.CloseSocket(d->mySock.Descriptor(), false, false);
   m_nState = FT_STATE_DISCONNECTED;
 
   if (m_nFileDesc != -1)
@@ -1062,6 +1094,7 @@ void CFileTransferManager::CloseConnection()
 void *FileTransferManager_tep(void *arg)
 {
   CFileTransferManager *ftman = (CFileTransferManager *)arg;
+  CFileTransferManager::Private* const d = ftman->myPrivate;
 
   fd_set f_recv, f_send;
   struct timeval *tv;
@@ -1093,8 +1126,8 @@ void *FileTransferManager_tep(void *arg)
     FD_ZERO(&f_send);
     if (ftman->m_nState == FT_STATE_SENDINGxFILE)
     {
-      FD_SET(ftman->ftSock.Descriptor(), &f_send);
-      // No need to check "l" as ftSock is already in the read list
+      FD_SET(d->mySock.Descriptor(), &f_send);
+      // No need to check "l" as mySock is already in the read list
     }
 
     // Prepare max timeout if necessary
@@ -1153,7 +1186,7 @@ void *FileTransferManager_tep(void *arg)
         // Connection on the server port ---------------------------------------
         else if (nCurrentSocket == ftman->ftServer.Descriptor())
         {
-          if (ftman->ftSock.Descriptor() != -1)
+          if (d->mySock.Descriptor() != -1)
           {
             gLog.warning(tr("File Transfer: Receiving repeat incoming connection."));
 
@@ -1164,10 +1197,10 @@ void *FileTransferManager_tep(void *arg)
           }
           else
           {
-            if (ftman->ftServer.RecvConnection(ftman->ftSock))
+            if (ftman->ftServer.RecvConnection(d->mySock))
             {
-              ftman->sockman.AddSocket(&ftman->ftSock);
-              ftman->sockman.DropSocket(&ftman->ftSock);
+              ftman->sockman.AddSocket(&d->mySock);
+              ftman->sockman.DropSocket(&d->mySock);
 
               ftman->m_nState = FT_STATE_HANDSHAKE;
               gLog.info(tr("File Transfer: Received connection."));
@@ -1180,11 +1213,11 @@ void *FileTransferManager_tep(void *arg)
         }
 
         // Message from connected socket----------------------------------------
-        else if (nCurrentSocket == ftman->ftSock.Descriptor())
+        else if (nCurrentSocket == d->mySock.Descriptor())
         {
-          ftman->ftSock.Lock();
+          d->mySock.Lock();
           bool ok = ftman->ProcessPacket();
-          ftman->ftSock.Unlock();
+          d->mySock.Unlock();
           if (!ok)
           {
             ftman->CloseConnection();
@@ -1201,11 +1234,11 @@ void *FileTransferManager_tep(void *arg)
       }
       else if (FD_ISSET(nCurrentSocket, &f_send))
       {
-        if (nCurrentSocket == ftman->ftSock.Descriptor())
+        if (nCurrentSocket == d->mySock.Descriptor())
         {
-          ftman->ftSock.Lock();
+          d->mySock.Lock();
           bool ok = ftman->SendFilePacket();
-          ftman->ftSock.Unlock();
+          d->mySock.Unlock();
           if (!ok)
           {
             ftman->CloseConnection();
@@ -1274,13 +1307,13 @@ void *FileWaitForSignal_tep(void *arg)
 
   if (bConnected)
   {
-    if (rc->m->ftSock.Descriptor() != -1)
+    if (rc->m->myPrivate->mySock.Descriptor() != -1)
     {
       gLog.warning(tr("File Transfer: Attempted connection when already connected."));
     }
     else
     {
-      rc->m->ftSock.TransferConnectionFrom(s);
+      rc->m->myPrivate->mySock.TransferConnectionFrom(s);
       bConnected = rc->m->SendFileHandshake();
       rc->m->myThreadPipe.putChar('R');
     }
@@ -1340,5 +1373,7 @@ CFileTransferManager::~CFileTransferManager()
     if (*fiter == this) break;
   }
   if (fiter != ftmList.end()) ftmList.erase(fiter);
+
+  delete myPrivate;
 }
 
